summaryrefslogtreecommitdiffstats
path: root/src/focusedwidgets.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 14:58:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 14:58:21 -0600
commit7864df7a5e0a69bb3e525ec3e47256bdcbf2832b (patch)
tree3aa53b371fc2482fb6bea9f8eca16b9524c1b332 /src/focusedwidgets.h
parent3cedb6a5f7a9c3e0c04303289e025ce6fe91e164 (diff)
downloadbasket-7864df7a5e0a69bb3e525ec3e47256bdcbf2832b.tar.gz
basket-7864df7a5e0a69bb3e525ec3e47256bdcbf2832b.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/focusedwidgets.h')
-rw-r--r--src/focusedwidgets.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/focusedwidgets.h b/src/focusedwidgets.h
index f757fce..b710e34 100644
--- a/src/focusedwidgets.h
+++ b/src/focusedwidgets.h
@@ -66,8 +66,8 @@ class FocusedColorCombo : public KColorCombo
void returnPressed2();
};
-// TODO: Rename to EscapableKFontCombo
-class FocusedFontCombo : public KFontCombo
+// TODO: Rename to EscapableTDEFontCombo
+class FocusedFontCombo : public TDEFontCombo
{
Q_OBJECT